@@ -62,6 +62,8 @@ public class UsbSerialHelper extends BroadcastReceiver {
     createDevice(0x0403, 0x6015), // Digifly AIR (FT X-Series)
     createDevice(0x0483, 0x5740), // SoftRF Dongle
     createDevice(0x239A, 0x8029), // SoftRF Badge
+    createDevice(0x2341, 0x804d), // SoftRF Academy
+    createDevice(0x1d50, 0x6089), // SoftRF ES
 
     createDevice(0x0403, 0x6001), // FT232AM, FT232BM, FT232R FT245R,
     createDevice(0x0403, 0x6010), // FT2232D, FT2232H
