@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -28,7 +28,8 @@ Copyright_License {
 
 struct MoreData;
 struct DerivedInfo;
-struct ThermalBandInfo;
+class ThermalEncounterBand;
+class ThermalEncounterCollection;
 struct ComputerSettings;
 
 /**
@@ -43,7 +44,11 @@ public:
   void Reset();
 
   void Compute(const MoreData &basic, const DerivedInfo &calculated,
-               ThermalBandInfo &tbi, const ComputerSettings &settings);
+               ThermalEncounterBand &tbe,
+               ThermalEncounterCollection &tbc,
+               const ComputerSettings &settings);
+private:
+  bool in_encounter;
 };
 
 #endif
