@@ -26,6 +26,9 @@ Copyright_License {
 
 #include "util/StaticArray.hxx"
 #include "Math/Vector.hpp"
+#include "time/Stamp.hpp"
+
+#include <chrono>
 
 /**
  * Structure to hold a single wind measurement
@@ -40,15 +43,15 @@ struct WindMeasurement
   /**
    * Time of fix.
    */
-  unsigned time;
+  TimeStamp time;
   double altitude;               /**< Altitude of fix */
 
-  constexpr unsigned Score(unsigned _time) const {
+  constexpr unsigned Score(TimeStamp _time) const noexcept {
     // Calculate the score of this item. The item with the highest
     // score is the least important one.  We may need to adjust the
     // proportion of the quality and the elapsed time. Currently, one
     // quality-point (scale: 1 to 5) is equal to 10 minutes.
-    return 600 * (6 - quality) + (_time - time);
+    return 600 * (6 - quality) + (_time - time).count();
   }
 };
 
@@ -67,10 +70,12 @@ public:
    * if no valid vector could be calculated (for instance: too little or
    * too low quality data).
    */
-  const Vector getWind(unsigned now, double alt, bool &found) const;
+  const Vector getWind(TimeStamp now, double alt,
+                       bool &found) const;
 
   /** Adds the windvector vector with quality quality to the list. */
-  void addMeasurement(unsigned time, const SpeedVector &vector,
+  void addMeasurement(TimeStamp time,
+                      const SpeedVector &vector,
                       double alt, unsigned quality);
 
   void Reset();
@@ -81,7 +86,7 @@ protected:
    * removed if the list is too full. Reimplemented from LimitedList.
    */
   [[gnu::pure]]
-  unsigned int getLeastImportantItem(unsigned now);
+  unsigned int getLeastImportantItem(TimeStamp now) noexcept;
 };
 
 #endif
