@@ -43,9 +43,11 @@ FilePicker(const TCHAR *caption, FileDataField &df,
 
   const TCHAR *extra_caption = nullptr;
 #ifdef HAVE_DOWNLOAD_MANAGER
-  if (df.GetFileType() != FileType::UNKNOWN &&
-      Net::DownloadManager::IsAvailable())
-    extra_caption = _("Download");
+  // with FileType::IGC don't show the 'Download'-Button!
+  if (df.GetFileType() != FileType::IGC && 
+    df.GetFileType() != FileType::UNKNOWN &&
+    Net::DownloadManager::IsAvailable())
+      extra_caption = _("Download");
 #endif
 
   int i = ComboPicker(caption, combo_list, help_text, false, extra_caption);
