@@ -22,6 +22,7 @@ Copyright_License {
 */
 
 #include "LayoutConfigPanel.hpp"
+#include "ui/canvas/Features.hpp" // for DRAW_MOUSE_CURSOR
 #include "Profile/ProfileKeys.hpp"
 #include "Profile/Profile.hpp"
 #include "Form/DataField/Enum.hpp"
@@ -261,7 +262,7 @@ LayoutConfigPanel::Save(bool &_changed) noexcept
 #ifdef ANDROID
   changed |= SaveValue(FullScreen, ProfileKeys::FullScreen,
                        ui_settings.display.full_screen);
-  native_view->SetFullScreen(ui_settings.display.full_screen);
+  native_view->SetFullScreen(Java::GetEnv(), ui_settings.display.full_screen);
 #endif
 
   bool orientation_changed = false;
