@@ -31,12 +31,14 @@ Copyright_License {
 #include "Logger/NMEALogger.hpp"
 #include "UtilsSettings.hpp"
 #include "Components.hpp"
+#include "Units/Group.hpp"
 
 using namespace std::chrono;
 
 enum ControlIndex {
   PilotName,
   CoPilotName,
+  CrewWeightTemplate,
   LoggerTimeStepCruise,
   LoggerTimeStepCircling,
   DisableAutoLogger,
@@ -74,6 +76,13 @@ LoggerConfigPanel::Prepare(ContainerWindow &parent,
 
   AddText(_("CoPilot name"), nullptr, logger.copilot_name);
 
+  AddFloat(_("Crew weight default"),
+            _("Default for all weight loaded to the glider beyond the empty weight and besides "
+                "the water ballast."),
+            _T("%.0f %s"), _T("%.0f"),
+            0, 300, 5, false, UnitGroup::MASS,
+            logger.crew_mass_template);
+
   AddDuration(_("Time step cruise"),
               _("This is the time interval between logged points when not circling."),
               seconds{1}, seconds{30}, seconds{1}, logger.time_step_cruise);
@@ -116,6 +125,9 @@ LoggerConfigPanel::Save(bool &changed) noexcept
   changed |= SaveValue(CoPilotName, ProfileKeys::CoPilotName,
                        logger.copilot_name);
 
+  changed |= SaveValue(CrewWeightTemplate, UnitGroup::MASS, ProfileKeys::CrewWeightTemplate,
+                       logger.crew_mass_template);
+
   changed |= SaveValue(LoggerTimeStepCruise, ProfileKeys::LoggerTimeStepCruise,
                        logger.time_step_cruise);
 
