@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -21,17 +21,16 @@ Copyright_License {
 }
 */
 
-#ifndef OLC_RULES_HPP
-#define OLC_RULES_HPP
+#ifndef CONTEST_RULES_HPP
+#define CONTEST_RULES_HPP
 
-#include "Compiler.h"
-
-#include <stdint.h>
+#include <cstdint>
 #include <tchar.h>
 
 enum class Contest : uint8_t;
 
-gcc_const
-const TCHAR* ContestToString(Contest contest);
+[[gnu::const]]
+const TCHAR *
+ContestToString(Contest contest) noexcept;
 
 #endif
