@@ -25,7 +25,6 @@
 
 #include "Geo/GeoPoint.hpp"
 #include "Engine/Waypoint/Ptr.hpp"
-#include "Engine/Waypoint/Waypoint.hpp"
 #include "Math/Angle.hpp"
 
 #include <list>
@@ -44,35 +43,13 @@ public:
     double actual_in;
     Angle bearing;
 
-    NearWaypoint(WaypointPtr &&_waypoint, const GeoPoint& _location) noexcept
-      :waypoint(std::move(_waypoint)),
-       location(_location), leg_in(0), actual_in(0) {
-      range = location.Distance(waypoint->location);
-    }
+    NearWaypoint(WaypointPtr &&_waypoint, const GeoPoint &_location) noexcept;
 
-    NearWaypoint(WaypointPtr &&_waypoint, const GeoPoint& _location,
-                 const NearWaypoint& previous) noexcept
-      :waypoint(std::move(_waypoint)), location(_location) {
-      range = location.Distance(waypoint->location);
-      update_leg(previous);
-    }
+    NearWaypoint(WaypointPtr &&_waypoint, const GeoPoint &_location,
+                 const NearWaypoint &previous) noexcept;
 
-    bool update_location(const GeoPoint &location_now) noexcept {
-      auto range_now = location_now.Distance(waypoint->location);
-      if (range_now < range) {
-        range = range_now;
-        location = location_now;
-        return true;
-      }
-      return false;
-      // TODO: or if distance from previous tp to here is greater than leg (and wasnt previously)
-    }
-
-    void update_leg(const NearWaypoint& previous) noexcept {
-      leg_in = previous.waypoint->location.Distance(waypoint->location);
-      actual_in = previous.location.Distance(location);
-      bearing = previous.location.Bearing(location);
-    }
+    bool update_location(const GeoPoint &location_now) noexcept;
+    void update_leg(const NearWaypoint &previous) noexcept;
   };
 
   typedef std::list<NearWaypoint> NearWaypointList;
