@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -39,11 +39,13 @@ FAITriangleTaskFactory::FAITriangleTaskFactory(OrderedTask& _task,
 {
 }
 
-bool 
-FAITriangleTaskFactory::Validate()
+TaskValidationErrorSet
+FAITriangleTaskFactory::Validate() const noexcept
 {
+  auto errors = FAITaskFactory::Validate();
 
-  bool valid = FAITaskFactory::Validate();
+  if (!FAITriangleValidator::Validate(task))
+    errors |= TaskValidationErrorType::WRONG_SHAPE;
 
-  return valid && FAITriangleValidator::Validate(task);
+  return errors;
 }
