@@ -1,7 +1,7 @@
 /* Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -21,20 +21,22 @@
  */
 
 #include "Gradient.hpp"
-#include "Util/Clamp.hpp"
+#include "util/Clamp.hpp"
 
-fixed
-AngleToGradient(const fixed d)
+#include <math.h>
+
+double
+AngleToGradient(const double d) noexcept
 {
-  if (d != fixed(0)) {
-    return Clamp(fixed(1) / d, fixed(-999), fixed(999));
+  if (d != 0) {
+    return Clamp(1. / d, -999., 999.);
   } else {
-    return fixed(999);
+    return 999;
   }
 }
 
 bool
-GradientValid(const fixed d)
+GradientValid(const double d) noexcept
 {
-  return fabs(d) < fixed(999);
+  return fabs(d) < 999;
 }
