@@ -34,10 +34,10 @@ class GeoBounds;
 class SearchPointVector: public std::vector<SearchPoint> {
 public:
   template<typename... Args>
-  SearchPointVector(Args&&... args)
+  SearchPointVector(Args&&... args) noexcept
     :std::vector<SearchPoint>(std::forward<Args>(args)...) {}
 
-  bool PruneInterior();
+  bool PruneInterior() noexcept;
 
   /**
    * Apply convex pruning algorithm with increasing tolerance
@@ -45,41 +45,41 @@ public:
    *
    * @return True if input was modified
    */
-  bool ThinToSize(const unsigned max_size);
+  bool ThinToSize(const unsigned max_size) noexcept;
 
-  void Project(const FlatProjection &tp);
+  void Project(const FlatProjection &tp) noexcept;
 
   [[gnu::pure]]
-  FlatGeoPoint NearestPoint(const FlatGeoPoint &p) const;
+  FlatGeoPoint NearestPoint(const FlatGeoPoint &p) const noexcept;
 
   /** Find iterator of nearest point, assuming polygon is convex */
   [[gnu::pure]]
-  const_iterator NearestIndexConvex(const FlatGeoPoint &p) const;
+  const_iterator NearestIndexConvex(const FlatGeoPoint &p) const noexcept;
 
   [[gnu::pure]]
-  bool IntersectsWith(const FlatRay &ray) const;
+  bool IntersectsWith(const FlatRay &ray) const noexcept;
 
   [[gnu::pure]]
-  FlatBoundingBox CalculateBoundingbox() const;
+  FlatBoundingBox CalculateBoundingbox() const noexcept;
 
   [[gnu::pure]]
-  GeoBounds CalculateGeoBounds() const;
+  GeoBounds CalculateGeoBounds() const noexcept;
 
   /** increment iterator, wrapping around to start if required */
   [[gnu::pure]]
-  const_iterator NextCircular(const_iterator i) const;
+  const_iterator NextCircular(const_iterator i) const noexcept;
 
   /** decreement iterator, wrapping around to last item if required */
   [[gnu::pure]]
-  const_iterator PreviousCircular(const_iterator i) const;
+  const_iterator PreviousCircular(const_iterator i) const noexcept;
 
   /** Is the given GeoPoint inside the polygon of SearchPoints? */
   [[gnu::pure]]
-  bool IsInside(const GeoPoint &pt) const;
+  bool IsInside(const GeoPoint &pt) const noexcept;
 
   /** Is the given FlatGeoPoint inside the polygon of SearchPoints? */
   [[gnu::pure]]
-  bool IsInside(const FlatGeoPoint &pt) const;
+  bool IsInside(const FlatGeoPoint &pt) const noexcept;
 };
 
 #endif
