@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -33,7 +33,7 @@ Copyright_License {
 class MessageOperationEnvironment : public QuietOperationEnvironment {
 public:
   /* virtual methods from class OperationEnvironment */
-  void SetErrorMessage(const TCHAR *text) override;
+  void SetErrorMessage(const TCHAR *text) noexcept override;
 };
 
 #endif
