@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -40,10 +40,39 @@ public:
   /**
    * @return the row height (including top and bottom padding)
    */
-  unsigned CalculateLayout(const Font &font);
+  unsigned CalculateLayout(const Font &font) noexcept;
 
   void DrawTextRow(Canvas &canvas, const PixelRect &rc,
-                   const TCHAR *text) const;
+                   const TCHAR *text) const noexcept;
+
+  /**
+   * Returns the minimum X coordinate of the column after the given
+   * text.
+   */
+  [[gnu::pure]]
+  int NextColumn(Canvas &canvas, const PixelRect &rc,
+                 const TCHAR *text) const noexcept;
+
+  /**
+   * Combine DrawTextRow() and NextColumn().
+   */
+  int DrawColumn(Canvas &canvas, const PixelRect &rc,
+                 const TCHAR *text) const noexcept;
+
+  /**
+   * Returns the maximum X coordinate of the column before the given
+   * text.
+   */
+  [[gnu::pure]]
+  int PreviousRightColumn(Canvas &canvas, const PixelRect &rc,
+                          const TCHAR *text) const noexcept;
+
+  /**
+   * Draws a right-aligned column and returns the new "right"
+   * coordinate.
+   */
+  int DrawRightColumn(Canvas &canvas, const PixelRect &rc,
+                      const TCHAR *text) const noexcept;
 };
 
 #endif
