@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,22 +26,18 @@ Copyright_License {
 #include "SaveFile.hpp"
 #include "LocalPath.hpp"
 #include "Engine/Task/Ordered/OrderedTask.hpp"
+#include "system/Path.hpp"
 
-#include <windef.h> // for MAX_PATH
-
-bool
-ProtectedTaskManager::TaskSave(const TCHAR* path)
+void
+ProtectedTaskManager::TaskSave(Path path)
 {
-  OrderedTask* task = TaskClone();
-  bool retval = SaveTask(path, *task);
-  delete task;
-  return retval;
+  std::unique_ptr<OrderedTask> task(TaskClone());
+  SaveTask(path, *task);
 }
 
-bool
+void
 ProtectedTaskManager::TaskSaveDefault()
 {
-  TCHAR buffer[MAX_PATH];
-  const auto path = LocalPath(buffer, default_task_path);
-  return TaskSave(path);
+  const auto path = LocalPath(default_task_path);
+  TaskSave(path);
 }
