@@ -1,7 +1,7 @@
 #ifndef _MAPSERVER_CONFIG_H
 #define _MAPSERVER_CONFIG_H
 
-#if !defined(WIN32) && !defined(__APPLE__)
+#if !defined(_WIN32) && !defined(__APPLE__)
 #include <features.h>
 #endif
 
@@ -10,7 +10,7 @@
 #define HAVE_STRCASESTR 1
 #define HAVE_STRDUP 1
 
-#if !defined(__GLIBC__) && !defined(WIN32)
+#if !defined(__GLIBC__) && !defined(_WIN32)
 #define HAVE_STRLCAT 1
 #define HAVE_STRLCPY 1
 #endif
