@@ -37,10 +37,6 @@ Copyright_License {
 #include <winuser.h>
 #endif
 
-#ifdef USE_VIDEOCORE
-#include <bcm_host.h>
-#endif
-
 /**
  * Returns the screen dimension rect to be used
  * @return The screen dimension rect to be used
@@ -56,11 +52,6 @@ SystemWindowSize()
   return { width, height };
 #elif defined(ANDROID)
   return native_view->GetSize();
-#elif defined(USE_VIDEOCORE)
-  uint32_t width, height;
-  return graphics_get_display_size(0, &width, &height) >= 0
-    ? PixelSize(width, height)
-    : PixelSize(640, 480);
 #else
   /// @todo implement this properly for SDL/UNIX
   return { CommandLine::width, CommandLine::height };
