@@ -271,6 +271,9 @@ class RowFormWidget : public WindowWidget {
      * Hide the Window/Widget, but do not update the #visible flag.
      */
     void Hide() noexcept;
+
+    [[gnu::pure]]
+    bool HasFocus() const noexcept;
   };
 
   const DialogLook &look;
@@ -591,6 +594,14 @@ public:
    */
   void LoadValueDuration(unsigned i, std::chrono::seconds value) noexcept;
 
+  /**
+   * Return the raw text of the #WndProperty, bypassing the
+   * #DataField.
+   */
+  const TCHAR *GetText(unsigned i) const noexcept {
+    return GetControl(i).GetText();
+  }
+
   /**
    * Clear the value of the specified row.  This bypasses the
    * DataField which may be attached to the control.  Use this method
@@ -747,6 +758,7 @@ public:
   void Show(const PixelRect &rc) noexcept override;
   void Move(const PixelRect &rc) noexcept override;
   bool SetFocus() noexcept override;
+  bool HasFocus() const noexcept override;
 };
 
 #endif
