@@ -23,12 +23,10 @@ Copyright_License {
 
 #include "Texture.hpp"
 #include "Globals.hpp"
-#include "ui/opengl/Features.hpp"
 #include "VertexPointer.hpp"
 #include "ui/dim/BulkPoint.hpp"
 #include "Asset.hpp"
 #include "Scope.hpp"
-#include "util/Compiler.h"
 
 #include <glm/gtc/type_ptr.hpp>
 
@@ -47,14 +45,14 @@ NextPowerOfTwo(unsigned i) noexcept
   return p;
 }
 
-gcc_const
+[[gnu::const]]
 static inline unsigned
 ValidateTextureSize(unsigned i) noexcept
 {
   return OpenGL::texture_non_power_of_two ? i : NextPowerOfTwo(i);
 }
 
-gcc_const
+[[gnu::const]]
 static inline PixelSize
 ValidateTextureSize(PixelSize size) noexcept
 {
