@@ -30,7 +30,6 @@ Copyright_License {
 #ifdef ENABLE_OPENGL
 #include "ui/dim/Rect.hpp"
 #include "ui/canvas/opengl/Init.hpp"
-#include "ui/opengl/Features.hpp"
 #include "Math/Point2D.hpp"
 #else
 #include "ui/canvas/memory/Export.hpp"
@@ -55,25 +54,9 @@ Copyright_License {
 
 #include <cassert>
 
-#ifndef ENABLE_OPENGL
-
-PixelRect
-TopCanvas::GetRect() const
+TopCanvas::TopCanvas(UI::Display &_display, SDL_Window *_window)
+  :display(_display), window(_window)
 {
-  assert(IsDefined());
-
-  int width, height;
-  ::SDL_GetWindowSize(window, &width, &height);
-  return { 0, 0, width, height };
-}
-
-#endif
-
-void
-TopCanvas::Create(SDL_Window *_window)
-{
-  window = _window;
-
 #ifdef USE_MEMORY_CANVAS
   renderer = SDL_CreateRenderer(window, -1, 0);
   if (renderer == nullptr)
@@ -81,7 +64,7 @@ TopCanvas::Create(SDL_Window *_window)
                              window, -1, 0, ::SDL_GetError());
 
   int width, height;
-  SDL_GetWindowSize(window, &width, &height);
+  SDL_GetRendererOutputSize(renderer, &width, &height);
   texture = SDL_CreateTexture(renderer, SDL_PIXELFORMAT_RGB888,
                               SDL_TEXTUREACCESS_STREAMING,
                               width, height);
@@ -97,6 +80,8 @@ TopCanvas::Create(SDL_Window *_window)
     throw FormatRuntimeError("SDL_GL_CreateContext(%p) has failed: %s",
                              window, ::SDL_GetError());
 
+  /* this is usually done by OpenGL::Display, but libSDL doesn't allow
+     that */
   OpenGL::SetupContext();
 
   SetupViewport(GetNativeSize());
@@ -107,8 +92,7 @@ TopCanvas::Create(SDL_Window *_window)
 #endif
 }
 
-void
-TopCanvas::Destroy()
+TopCanvas::~TopCanvas() noexcept
 {
 #if !defined(ENABLE_OPENGL) && defined(GREYSCALE)
   buffer.Free();
@@ -122,7 +106,7 @@ TopCanvas::Destroy()
 #ifdef ENABLE_OPENGL
 
 PixelSize
-TopCanvas::GetNativeSize() const
+TopCanvas::GetNativeSize() const noexcept
 {
   int w, h;
   SDL_GL_GetDrawableSize(window, &w, &h);
@@ -133,8 +117,22 @@ TopCanvas::GetNativeSize() const
 
 #ifdef USE_MEMORY_CANVAS
 
+#ifndef GREYSCALE
+
+PixelSize
+TopCanvas::GetSize() const noexcept
+{
+  int width, height;
+  if (SDL_QueryTexture(texture, nullptr, nullptr, &width, &height) != 0)
+    return {};
+
+  return PixelSize(width, height);
+}
+
+#endif // !GREYSCALE
+
 void
-TopCanvas::OnResize(PixelSize new_size)
+TopCanvas::OnResize(PixelSize new_size) noexcept
 {
   int texture_width, texture_height;
   Uint32 texture_format;
@@ -159,7 +157,7 @@ TopCanvas::OnResize(PixelSize new_size)
 #endif
 }
 
-#endif
+#endif // USE_MEMORY_CANVAS
 
 #ifdef GREYSCALE
 
@@ -260,7 +258,7 @@ TopCanvas::Lock()
 }
 
 void
-TopCanvas::Unlock()
+TopCanvas::Unlock() noexcept
 {
 #ifndef GREYSCALE
   SDL_UnlockTexture(texture);
@@ -284,7 +282,6 @@ TopCanvas::Flip()
                     texture, buffer);
 #endif
 
-  ::SDL_RenderClear(renderer);
   ::SDL_RenderCopy(renderer, texture, nullptr, nullptr);
   ::SDL_RenderPresent(renderer);
 
