@@ -71,6 +71,12 @@ LargeTextWindow::ScrollVertically(int delta_lines)
   else if (new_origin > row_count - visible_rows)
     new_origin = row_count - visible_rows;
 
+  ScrollTo(new_origin);
+}
+
+void
+LargeTextWindow::ScrollTo(unsigned new_origin) noexcept
+{
   if (new_origin != origin) {
     origin = new_origin;
     Invalidate();
@@ -160,6 +166,24 @@ LargeTextWindow::OnKeyDown(unsigned key_code)
   case KEY_DOWN:
     ScrollVertically(1);
     return true;
+
+  case KEY_HOME:
+    ScrollTo(0);
+    return true;
+
+  case KEY_END:
+    if (unsigned visible_rows = GetVisibleRows(), row_count = GetRowCount();
+        visible_rows < row_count)
+      ScrollTo(row_count - visible_rows);
+    return true;
+
+  case KEY_PRIOR:
+    ScrollVertically(-(int)GetVisibleRows());
+    return true;
+
+  case KEY_NEXT:
+    ScrollVertically(GetVisibleRows());
+    return true;
   }
 
   return NativeWindow::OnKeyDown(key_code);
