@@ -61,14 +61,14 @@ namespace UI {
 LinuxInputDevice::LinuxInputDevice(EventQueue &_queue, MergeMouse &_merge)
   :queue(_queue), merge(_merge),
    edit_position(0, 0), public_position(0, 0),
-   socket_event(queue.GetEventLoop(), BIND_THIS_METHOD(OnSocketReady))
+   event(queue.GetEventLoop(), BIND_THIS_METHOD(OnSocketReady))
 {
 }
 
 /**
  * Check if the EVDEV supports EV_ABS or EV_REL..
  */
-gcc_pure
+[[gnu::pure]]
 static bool
 IsPointerDevice(int fd)
 {
@@ -89,12 +89,12 @@ LinuxInputDevice::Open(const char *path)
     return false;
 
   _fd.SetNonBlocking();
-  socket_event.Open(SocketDescriptor::FromFileDescriptor(_fd));
-  socket_event.ScheduleRead();
+  event.Open(_fd);
+  event.ScheduleRead();
 
   min_x = max_x = min_y = max_y = 0;
 
-  is_pointer = IsPointerDevice(socket_event.GetSocket().Get());
+  is_pointer = IsPointerDevice(event.GetFileDescriptor().Get());
   if (is_pointer) {
     merge.AddPointer();
 
@@ -103,7 +103,7 @@ LinuxInputDevice::Open(const char *path)
       /* no need to do that on the Kobo, because we know its touch
          screen is well-calibrated */
 
-      const int fd = socket_event.GetSocket().Get();
+      const int fd = event.GetFileDescriptor().Get();
 
       input_absinfo abs;
       if (ioctl(fd, EVIOCGABS(ABS_X), &abs) == 0) {
@@ -133,13 +133,13 @@ LinuxInputDevice::Close()
   if (is_pointer)
     merge.RemovePointer();
 
-  socket_event.Close();
+  event.Close();
 }
 
 inline void
 LinuxInputDevice::Read()
 {
-  FileDescriptor fd = socket_event.GetSocket().ToFileDescriptor();
+  FileDescriptor fd = event.GetFileDescriptor();
 
   struct input_event buffer[64];
   const auto nbytes = fd.Read(buffer, sizeof(buffer));
