@@ -57,7 +57,7 @@ public:
    * iteration, because it is assumed that the event loop runs
    * for a negligible duration.
    */
-  gcc_pure
+  [[gnu::pure]]
   const auto &SteadyNow() const noexcept {
     return steady_clock_cache.now();
   }
