@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@ Copyright_License {
 
 #include "DebugReplayFile.hpp"
 #include "Device/Parser.hpp"
-#include "Time/ReplayClock.hpp"
+#include "time/ReplayClock.hpp"
 
 #include <memory>
 
@@ -48,7 +48,7 @@ private:
 public:
   virtual bool Next();
 
-  static DebugReplay* Create(const char *input_file, const tstring &driver_name);
+  static DebugReplay *Create(Path input_file, const tstring &driver_name);
 };
 
 #endif
