@@ -28,10 +28,10 @@ Copyright_License {
 
 #include "Terrain/RasterTileCache.hpp"
 #include "Terrain/Loader.hpp"
+#include "Operation/ConsoleOperationEnvironment.hpp"
 #include "system/Args.hpp"
 #include "system/ConvertPathName.hpp"
 #include "io/ZipArchive.hpp"
-#include "Operation/Operation.hpp"
 #include "util/PrintException.hxx"
 
 #include <stdio.h>
@@ -49,7 +49,7 @@ try {
   RasterTileCache rtc;
 
   {
-    NullOperationEnvironment operation;
+    ConsoleOperationEnvironment operation;
     LoadTerrainOverview(archive.get(), rtc, operation);
   }
 
